@@ -1,28 +1,13 @@
 import requests
 import time
-import hmac
-import hashlib
 
 from .helper import convert_symbol_convention_from, convert_symbol_convention_to, convert_symboldata_format
-
 from .defines import *
+from .baseclient import BaseClient
 
-class Client:
-    id = 'trbinance'
-    name = 'TrBinance'
-
-    def __init__(self, api_key="", secret_key=""):
-        self.api_key = api_key
-        self.secret_key = secret_key
-        self.session = requests.Session()
-        self.session.headers.update({'X-MBX-APIKEY': api_key})
-        self.urls = {
-            "base" : "https://www.trbinance.com/open/v1",
-            "type1" : "https://api.binance.me/api"
-        }
-
-        self.markets = None
-        self.symbols = None
+class Client(BaseClient):
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
 
     def _request(self, method, endpoint, security_type, symbol_type=0, params=None):
         if symbol_type == 1:
@@ -45,13 +30,8 @@ class Client:
                 raise Exception('Invalid method')
 
         response.raise_for_status()
-        
         return self._handle_response(response)
 
-    def _generate_signature(self, params):
-        query_string = '&'.join([f"{key}={value}" for key, value in params.items()])
-        return hmac.new(self.secret_key.encode('utf-8'), query_string.encode('utf-8'), hashlib.sha256).hexdigest()
-
     def _handle_response(self, raw_response):
         response = raw_response.json()
         if "code" in response:
@@ -61,7 +41,7 @@ class Client:
             elif response['code'] != 0:
                 raise Exception(f"Error {response['code']}: {response['msg']}")
         return response
-
+    
     def check_server_time(self):
         endpoint = '/common/time'
         response = self._request('GET', endpoint, 'public')
@@ -303,7 +283,6 @@ class Client:
         resp = self._request("GET", endpoint, "private", symbol_type=0, params=params)
         return resp["data"]
 
-
     def deposit_address(self, asset, network, **kwargs):
         params = {
             'asset': asset,
